@@ -1,4 +1,5 @@
 """Configuration for myst-nb."""
+
 import dataclasses as dc
 from enum import Enum
 from typing import Any, Callable, Dict, Iterable, Literal, Optional, Sequence, Tuple
@@ -285,7 +286,7 @@ class NbParserConfig:
         default=False,
         metadata={
             "validator": instance_of(bool),
-            "help": "Merge stdout/stderr execution output streams",
+            "help": "Merge all stdout execution output streams; same with stderr",
             "sections": (
                 Section.global_lvl,
                 Section.file_lvl,
@@ -333,6 +334,20 @@ class NbParserConfig:
         },
     )
 
+    scroll_outputs: bool = dc.field(
+        default=False,
+        metadata={
+            "validator": instance_of(bool),
+            "help": "Make long cell outputs scrollable",
+            "sections": (
+                Section.global_lvl,
+                Section.file_lvl,
+                Section.cell_lvl,
+                Section.render,
+            ),
+        },
+    )
+
     code_prompt_show: str = dc.field(
         default="Show code cell {type}",
         metadata={
@@ -575,7 +590,7 @@ class NbParserConfig:
     def get_cell_level_config(
         self,
         field_name: str,
-        cell_metadata: Dict[str, Any],
+        cell_metadata: Any,
         warning_callback: Callable[[str, MystNBWarnings], Any],
     ) -> Any:
         """Get a configuration value at the cell level.
