@@ -1,4 +1,5 @@
 """Module for reading notebook formats from a string input."""
+
 from __future__ import annotations
 
 import dataclasses as dc
@@ -57,8 +58,11 @@ def create_nb_reader(
     :returns: the notebook reader, and the (potentially modified) MdParserConfig,
         or None if the input cannot be read as a notebook.
     """
-    # the import is here so this module can be loaded without sphinx
-    from sphinx.util import import_object
+
+    try:
+        from sphinx.util._importer import import_object
+    except ImportError:
+        from sphinx.util import import_object
 
     # get all possible readers
     readers = nb_config.custom_formats.copy()
@@ -68,14 +72,14 @@ def create_nb_reader(
     # we check suffixes ordered by longest first, to ensure we get the "closest" match
     iterator = sorted(readers.items(), key=lambda x: len(x[0]), reverse=True)
     for suffix, (reader, reader_kwargs, commonmark_only) in iterator:
-        if Path(path).suffix == suffix:
+        if str(Path(path)).endswith(suffix):
             if isinstance(reader, str):
                 # attempt to load the reader as an object path
                 reader = import_object(reader)
             if commonmark_only:
                 # Markdown cells should be read as Markdown only
                 md_config = dc.replace(md_config, commonmark_only=True)
-            return NbReader(partial(reader, **(reader_kwargs or {})), md_config)  # type: ignore
+            return NbReader(partial(reader, **(reader_kwargs or {})), md_config)
 
     # a Markdown file is a special case, since we only treat it as a notebook,
     # if it starts with certain "top-matter"
