@@ -1,4 +1,5 @@
 """The sphinx parser implementation for myst-nb."""
+
 from __future__ import annotations
 
 from collections import defaultdict
@@ -84,7 +85,7 @@ class Parser(MystParser):
         # create a reader for the notebook
         nb_reader = create_nb_reader(document_path, md_config, nb_config, inputstring)
         # If the nb_reader is None, then we default to a standard Markdown parser
-        if nb_reader is None:
+        if nb_reader is None or document.current_source.endswith("<translated>"):
             return super().parse(inputstring, document)
         notebook = nb_reader.read(inputstring)
 
@@ -491,10 +492,14 @@ class HideCodeCellNode(nodes.Element):
 
 def visit_HideCellInput(self: SphinxTranslator, node: HideCodeCellNode):
     classes = " ".join(node["classes"])
-    self.body.append(f'<details class="hide {classes}">\n')
+    self.body.append(f'<details class="admonition hide {classes}">\n')
     self.body.append('<summary aria-label="Toggle hidden content">\n')
-    self.body.append(f'<span class="collapsed">{escape(node["prompt_show"])}</span>\n')
-    self.body.append(f'<span class="expanded">{escape(node["prompt_hide"])}</span>\n')
+    self.body.append(
+        f'<p class="collapsed admonition-title">{escape(node["prompt_show"])}</p>\n'
+    )
+    self.body.append(
+        f'<p class="expanded admonition-title">{escape(node["prompt_hide"])}</p>\n'
+    )
     self.body.append("</summary>\n")
 
 
